@@ -1,9 +1,10 @@
-import process_pose_data.honeycomb_io
+import honeycomb_io
 import pandas as pd
 import numpy as np
 import logging
 from uuid import uuid4
 import datetime
+import dateutil
 import os
 import glob
 import pickle
@@ -26,6 +27,7 @@ def fetch_2d_pose_data_alphapose_local_time_segment(
     environment_id,
     time_segment_start,
     alphapose_subdirectory='prepared',
+    tree_structure='file-per-frame',
     filename='alphapose-results.json',
     json_format='cmu'
 ):
@@ -41,44 +43,136 @@ def fetch_2d_pose_data_alphapose_local_time_segment(
         minute=time_segment_start_utc.minute,
         second=time_segment_start_utc.second,
         alphapose_subdirectory=alphapose_subdirectory,
+        tree_structure=tree_structure,
         filename=filename
     )
     re_pattern = alphapose_data_file_re_pattern(
         base_dir=base_dir,
         alphapose_subdirectory=alphapose_subdirectory,
+        tree_structure=tree_structure,
         filename=filename
     )
     data_list = list()
-    for path in glob.iglob(glob_pattern):
-        m = re.match(re_pattern, path)
-        if not m:
-            raise ValueError('Regular expression does not match path: {}'.format(path))
-        assignment_id = m.group('assignment_id')
-        timestamp_video_file = datetime.datetime(
-            int(m.group('year_string')),
-            int(m.group('month_string')),
-            int(m.group('day_string')),
-            int(m.group('hour_string')),
-            int(m.group('minute_string')),
-            int(m.group('second_string')),
-            tzinfo=datetime.timezone.utc
-        )
-        with open(path, 'r') as fp:
-            pose_data_object = json.load(fp)
-        if len(pose_data_object) == 0:
-            continue
-        if json_format == 'cmu':
-            # JSON is a dict structure with an entry for each image
-            for image_filename, pose_data in pose_data_object.items():
-                frame_number = int(image_filename.split('.')[0])
-                timestamp = timestamp_video_file + datetime.timedelta(microseconds = 10**5*frame_number)
-                for pose in pose_data['bodies']:
-                    keypoint_data_array = np.asarray(pose['joints']).reshape((-1 , 3))
+    if tree_structure == 'file-per-frame':
+        for path in glob.iglob(glob_pattern):
+            m = re.match(re_pattern, path)
+            if not m:
+                raise ValueError('Regular expression does not match path: {}'.format(path))
+            assignment_id = m.group('assignment_id')
+            timestamp_video_file = datetime.datetime(
+                int(m.group('year_string')),
+                int(m.group('month_string')),
+                int(m.group('day_string')),
+                int(m.group('hour_string')),
+                int(m.group('minute_string')),
+                int(m.group('second_string')),
+                tzinfo=datetime.timezone.utc
+            )
+            frame_number = int(m.group('frame_number_string'))
+            with open(path, 'r') as fp:
+                pose_data_object = json.load(fp)
+            if len(pose_data_object) == 0:
+                continue
+            timestamp_json_string = pose_data_object.get('timestamp')
+            assignment_id_json = pose_data_object.get('assignment_id')
+            environment_id_json = pose_data_object.get('environment_id')
+            try:
+                timestamp_json = dateutil.parser.isoparse(timestamp_json_string)
+            except:
+                raise ValueError('Timestamp string in JSON \'{}\' cannot be parsed by dateutil.parser.isoparse()'.format(
+                    timestamp_json_string
+                ))
+            timestamp_path = timestamp_video_file + datetime.timedelta(microseconds = 10**5*frame_number)
+            if timestamp_json != timestamp_path:
+                raise ValueError('Timestamp in JSON \'{}\' does not match timestamp inferred from path \'{}\' for file \'{}\' (extracted frame number string \'{}\' resulting in frame number {})'.format(
+                    timestamp_json.isoformat(),
+                    timestamp_path.isoformat(),
+                    path,
+                    m.group('frame_number_string'),
+                    frame_number
+                ))
+            if assignment_id_json != assignment_id:
+                raise ValueError('Assignment ID in JSON \'{}\' does not match assignment ID inferred from path \'{}\' for file \'{}\''.format(
+                    assignment_id_json,
+                    assignment_id,
+                    path
+                ))
+            if environment_id_json != environment_id:
+                raise ValueError('Assignment ID in JSON \'{}\' does not match assignment ID inferred from path \'{}\' for file \'{}\''.format(
+                    environment_id_json,
+                    environment_id,
+                    path
+                ))
+            poses = pose_data_object.get('poses')
+            if poses is None:
+                raise ValueError('JSON in file \'{}\' does not contain \'poses\' field')
+            if len(poses) == 0:
+                continue
+            for pose in poses:
+                keypoints = np.asarray([[keypoint.get('x'), keypoint.get('y')] for keypoint in pose.get('keypoints')])
+                keypoint_quality = np.asarray([keypoint.get('quality')for keypoint in pose.get('keypoints')])
+                keypoints = np.where(keypoints == 0.0, np.nan, keypoints)
+                keypoint_quality = np.where(keypoint_quality == 0.0, np.nan, keypoint_quality)
+                pose_quality = pose.get('quality')
+                pose_2d_id = pose.get('pose_id')
+                data_list.append({
+                    'pose_2d_id': pose_2d_id,
+                    'timestamp': pd.to_datetime(timestamp_json),
+                    'assignment_id': assignment_id_json,
+                    'keypoint_coordinates_2d': keypoints,
+                    'keypoint_quality_2d': keypoint_quality,
+                    'pose_quality_2d': pose_quality
+                })
+    elif tree_structure == 'file-per-segment':
+        for path in glob.iglob(glob_pattern):
+            m = re.match(re_pattern, path)
+            if not m:
+                raise ValueError('Regular expression does not match path: {}'.format(path))
+            assignment_id = m.group('assignment_id')
+            timestamp_video_file = datetime.datetime(
+                int(m.group('year_string')),
+                int(m.group('month_string')),
+                int(m.group('day_string')),
+                int(m.group('hour_string')),
+                int(m.group('minute_string')),
+                int(m.group('second_string')),
+                tzinfo=datetime.timezone.utc
+            )
+            with open(path, 'r') as fp:
+                pose_data_object = json.load(fp)
+            if len(pose_data_object) == 0:
+                continue
+            if json_format == 'cmu':
+                # JSON is a dict structure with an entry for each image
+                for image_filename, pose_data in pose_data_object.items():
+                    frame_number = int(image_filename.split('.')[0])
+                    timestamp = timestamp_video_file + datetime.timedelta(microseconds = 10**5*frame_number)
+                    for pose in pose_data['bodies']:
+                        keypoint_data_array = np.asarray(pose['joints']).reshape((-1 , 3))
+                        keypoints = keypoint_data_array[:, :2]
+                        keypoint_quality = keypoint_data_array[:, 2]
+                        keypoints = np.where(keypoints == 0.0, np.nan, keypoints)
+                        keypoint_quality = np.where(keypoint_quality == 0.0, np.nan, keypoint_quality)
+                        pose_quality = pose.get('score')
+                        data_list.append({
+                            'pose_2d_id': uuid4().hex,
+                            'timestamp': pd.to_datetime(timestamp),
+                            'assignment_id': assignment_id,
+                            'keypoint_coordinates_2d': keypoints,
+                            'keypoint_quality_2d': keypoint_quality,
+                            'pose_quality_2d': pose_quality
+                        })
+            elif json_format == 'list':
+                # JSON is a list structure with an item for each pose
+                for pose_data in pose_data_object:
+                    frame_number = int(pose_data.get('image_id').split('.')[0])
+                    timestamp = timestamp_video_file + datetime.timedelta(microseconds = 10**5*frame_number)
+                    keypoint_data_array = np.asarray(pose_data['keypoints']).reshape((-1 , 3))
                     keypoints = keypoint_data_array[:, :2]
                     keypoint_quality = keypoint_data_array[:, 2]
                     keypoints = np.where(keypoints == 0.0, np.nan, keypoints)
                     keypoint_quality = np.where(keypoint_quality == 0.0, np.nan, keypoint_quality)
-                    pose_quality = pose.get('score')
+                    pose_quality = pose_data.get('score')
                     data_list.append({
                         'pose_2d_id': uuid4().hex,
                         'timestamp': pd.to_datetime(timestamp),
@@ -87,36 +181,21 @@ def fetch_2d_pose_data_alphapose_local_time_segment(
                         'keypoint_quality_2d': keypoint_quality,
                         'pose_quality_2d': pose_quality
                     })
-        elif json_format == 'list':
-            # JSON is a list structure with an item for each pose
-            for pose_data in pose_data_object:
-                frame_number = int(pose_data.get('image_id').split('.')[0])
-                timestamp = timestamp_video_file + datetime.timedelta(microseconds = 10**5*frame_number)
-                keypoint_data_array = np.asarray(pose_data['keypoints']).reshape((-1 , 3))
-                keypoints = keypoint_data_array[:, :2]
-                keypoint_quality = keypoint_data_array[:, 2]
-                keypoints = np.where(keypoints == 0.0, np.nan, keypoints)
-                keypoint_quality = np.where(keypoint_quality == 0.0, np.nan, keypoint_quality)
-                pose_quality = pose_data.get('score')
-                data_list.append({
-                    'pose_2d_id': uuid4().hex,
-                    'timestamp': pd.to_datetime(timestamp),
-                    'assignment_id': assignment_id,
-                    'keypoint_coordinates_2d': keypoints,
-                    'keypoint_quality_2d': keypoint_quality,
-                    'pose_quality_2d': pose_quality
-                })
-        else:
-            raise ValueError('JSON format specifier \'{}\' not recognized'.format(json_format))
+            else:
+                raise ValueError('JSON format specifier \'{}\' not recognized'.format(json_format))
+    else:
+        raise ValueError('Tree structure specification \'{}\' not recognized'.format(
+            tree_structure
+        ))
     df = pd.DataFrame(data_list)
     if len(df) == 0:
         logger.warning('No poses found for time segment starting at %04d/%02d/%02dT%02d:%02d:%02d. Returning empty data frame',
-            year,
-            month,
-            day,
-            hour,
-            minute,
-            second
+            time_segment_start_utc.year,
+            time_segment_start_utc.month,
+            time_segment_start_utc.day,
+            time_segment_start_utc.hour,
+            time_segment_start_utc.minute,
+            time_segment_start_utc.second
         )
         return df
     df.set_index('pose_2d_id', inplace=True)
@@ -145,7 +224,7 @@ def fetch_3d_poses_with_person_info(
         end=end,
         pose_processing_subdirectory=pose_processing_subdirectory
     )
-    person_info_df = process_pose_data.honeycomb_io.fetch_person_info(
+    person_info_df = honeycomb_io.fetch_person_info(
         environment_id=environment_id,
         client=client,
         uri=uri,
@@ -168,7 +247,7 @@ def fetch_3d_poses_with_identified_tracks_local(
     end=None,
     pose_processing_subdirectory='pose_processing'
 ):
-    pose_track_3d_identification_metadata = process_pose_data.local_io.fetch_data_local(
+    pose_track_3d_identification_metadata = fetch_data_local(
         base_dir=base_dir,
         pipeline_stage='pose_track_3d_identification',
         environment_id=environment_id,
@@ -223,7 +302,7 @@ def fetch_3d_poses_with_interpolated_tracks_local(
     end=None,
     pose_processing_subdirectory='pose_processing'
 ):
-    pose_track_3d_interpolation_metadata = process_pose_data.local_io.fetch_data_local(
+    pose_track_3d_interpolation_metadata = fetch_data_local(
         base_dir=base_dir,
         pipeline_stage='pose_track_3d_interpolation',
         environment_id=environment_id,
@@ -273,7 +352,7 @@ def fetch_3d_poses_with_uninterpolated_tracks_local(
     end=None,
     pose_processing_subdirectory='pose_processing'
 ):
-    pose_tracks_3d_metadata = process_pose_data.local_io.fetch_data_local(
+    pose_tracks_3d_metadata = fetch_data_local(
         base_dir=base_dir,
         pipeline_stage='pose_tracking_3d',
         environment_id=environment_id,
@@ -648,7 +727,9 @@ def alphapose_data_file_glob_pattern(
     hour=None,
     minute=None,
     second=None,
+    frame_number=None,
     alphapose_subdirectory='prepared',
+    tree_structure='file-per-frame',
     filename='alphapose-results.json'
 ):
     base_dir_string = base_dir
@@ -685,35 +766,70 @@ def alphapose_data_file_glob_pattern(
         second_string = '{:02d}'.format(second)
     else:
         second_string = '??'
-    glob_pattern = os.path.join(
-        base_dir_string,
-        alphapose_subdirectory_string,
-        environment_id_string,
-        camera_assignment_id_string,
-        year_string,
-        month_string,
-        day_string,
-        '-'.join([hour_string, minute_string, second_string]),
-        filename
-    )
+    if frame_number is not None:
+        frame_number_string = '{:d}'.format(frame_number)
+    else:
+        frame_number_string = '*'
+    if tree_structure == 'file-per-frame':
+        glob_pattern = os.path.join(
+            base_dir_string,
+            alphapose_subdirectory_string,
+            environment_id_string,
+            camera_assignment_id_string,
+            year_string,
+            month_string,
+            day_string,
+            '-'.join([hour_string, minute_string, second_string]),
+            'poses-{}.json'.format(frame_number_string)
+        )
+    elif tree_structure == 'file-per-segment':
+        glob_pattern = os.path.join(
+            base_dir_string,
+            alphapose_subdirectory_string,
+            environment_id_string,
+            camera_assignment_id_string,
+            year_string,
+            month_string,
+            day_string,
+            '-'.join([hour_string, minute_string, second_string]),
+            filename
+        )
+    else:
+        raise ValueError('Tree structure specification \'{}\' not recognized'.format(
+            tree_structure
+        ))
     return glob_pattern
 
 def alphapose_data_file_re_pattern(
     base_dir,
     alphapose_subdirectory='prepared',
+    tree_structure='file-per-frame',
     filename='alphapose-results.json'
 ):
-    re_pattern = os.path.join(
-        base_dir,
-        alphapose_subdirectory,
-        '(?P<environment_id>.+)',
-        '(?P<assignment_id>.+)',
-        '(?P<year_string>[0-9]{4})',
-        '(?P<month_string>[0-9]{2})',
-        '(?P<day_string>[0-9]{2})',
-        '(?P<hour_string>[0-9]{2})\-(?P<minute_string>[0-9]{2})\-(?P<second_string>[0-9]{2})',
-        filename
-    )
+    if tree_structure=='file-per-frame':
+        re_pattern = os.path.join(
+            base_dir,
+            alphapose_subdirectory,
+            '(?P<environment_id>.+)',
+            '(?P<assignment_id>.+)',
+            '(?P<year_string>[0-9]{4})',
+            '(?P<month_string>[0-9]{2})',
+            '(?P<day_string>[0-9]{2})',
+            '(?P<hour_string>[0-9]{2})\-(?P<minute_string>[0-9]{2})\-(?P<second_string>[0-9]{2})',
+            'poses-(?P<frame_number_string>[0-9]+)\.json'
+        )
+    elif tree_structure=='file-per-segment':
+        re_pattern = os.path.join(
+            base_dir,
+            alphapose_subdirectory,
+            '(?P<environment_id>.+)',
+            '(?P<assignment_id>.+)',
+            '(?P<year_string>[0-9]{4})',
+            '(?P<month_string>[0-9]{2})',
+            '(?P<day_string>[0-9]{2})',
+            '(?P<hour_string>[0-9]{2})\-(?P<minute_string>[0-9]{2})\-(?P<second_string>[0-9]{2})',
+            filename
+        )
     return re_pattern
 
 def convert_assignment_ids_to_camera_device_ids(
@@ -728,7 +844,7 @@ def convert_assignment_ids_to_camera_device_ids(
 ):
     if camera_device_id_lookup is None:
         assignment_ids = poses_2d_df['assignment_id'].unique().tolist()
-        camera_device_id_lookup = process_pose_data.honeycomb_io.fetch_camera_device_id_lookup(
+        camera_device_id_lookup = honeycomb_io.fetch_camera_device_id_lookup(
             assignment_ids=assignment_ids,
             client=client,
             uri=uri,
